@@ -1,7 +1,10 @@
 from __future__ import annotations
 
+import logging
 from typing import Any, Dict
 
+from rich.control import Control, ControlType
+
 from gptsh.interfaces import ApprovalPolicy
 
 
@@ -9,6 +12,21 @@ def _canon(n: str) -> str:
     return str(n).lower().replace("-", "_").strip()
 
 
+def _best_effort_flush_stdin() -> None:
+    """Discard any pending keystrokes (e.g., stray newlines) before prompting.
+
+    Uses termios.tcflush on TTYs (Unix). No-op on unsupported platforms or errors.
+    """
+    import sys
+    try:
+        if sys.stdin.isatty():
+            import termios  # Unix-only
+            termios.tcflush(sys.stdin.fileno(), termios.TCIFLUSH)
+    except Exception as e:
+        # Best-effort: log at debug and continue if unavailable or any error occurs.
+        logging.debug("stdin flush skipped (termios/tty unavailable): %s", e, exc_info=True)
+
+
 class DefaultApprovalPolicy(ApprovalPolicy):
     def __init__(self, approved_map: Dict[str, list[str]] | None = None):
         self._approved = {k: list(v) for k, v in (approved_map or {}).items()}
@@ -46,6 +64,8 @@ class DefaultApprovalPolicy(ApprovalPolicy):
 
         arg_text = json.dumps(args, ensure_ascii=False) if isinstance(args, dict) else str(args)
         console = Console(stderr=True, soft_wrap=True)
+        # Clear any pending input (e.g., stray Enters) before asking
+        _best_effort_flush_stdin()
         choice = Confirm.ask(
             f"[grey50]Allow tool[/grey50] [dim yellow]{server}__{tool}[/dim yellow] [grey50]with args[/grey50] [dim]{arg_text}[/dim]?",
             choices=["y", "n"],
@@ -55,7 +75,10 @@ class DefaultApprovalPolicy(ApprovalPolicy):
         )
 
         # Cleanup confirm prompt
-        console.file.write("\x1b[1A\r\x1b[2K")
-        console.file.flush()
+        console.control(
+            Control.move(y=-1),
+            Control.move_to_column(0),
+            Control((ControlType.ERASE_IN_LINE, 2)),
+        )
 
         return bool(choice)
