@@ -29,6 +29,8 @@ class AgentConfig:
     tools: Optional[List[str]] = None  # None=all, []=disabled, [labels]=allow-list
     no_tools: bool = False
     output: Optional[str] = None  # text|markdown
+    sessions: Dict[str, Any] = field(default_factory=dict)
+    autoApprove: Optional[List[str]] = None  # Auto-approve tools by server or tool name
 
 
 @dataclass
@@ -41,7 +43,9 @@ def _as_dict(d: Optional[Dict[str, Any]]) -> Dict[str, Any]:
     return dict(d or {})
 
 
-def map_config_to_models(config: Dict[str, Any]) -> Tuple[Defaults, Dict[str, ProviderConfig], Dict[str, AgentConfig]]:
+def map_config_to_models(
+    config: Dict[str, Any],
+) -> Tuple[Defaults, Dict[str, ProviderConfig], Dict[str, AgentConfig]]:
     defaults = Defaults(
         default_agent=config.get("default_agent"),
         default_provider=config.get("default_provider"),
@@ -62,6 +66,7 @@ def map_config_to_models(config: Dict[str, Any]) -> Tuple[Defaults, Dict[str, Pr
         if not isinstance(a, dict):
             a = {}
         prompt_cfg = _as_dict(a.get("prompt"))
+        auto_approve = a.get("autoApprove")
         agents[name] = AgentConfig(
             name=name,
             provider=a.get("provider"),
@@ -69,9 +74,11 @@ def map_config_to_models(config: Dict[str, Any]) -> Tuple[Defaults, Dict[str, Pr
             reasoning_effort=a.get("reasoning_effort"),
             temperature=a.get("temperature"),
             prompt=AgentPrompt(system=prompt_cfg.get("system"), user=prompt_cfg.get("user")),
-            tools=list(a.get("tools")) if isinstance(a.get("tools"), list) else None,
+            tools=(a.get("tools") if isinstance(a.get("tools"), list) else None),
             no_tools=bool(a.get("no_tools", False)),
             output=a.get("output"),
+            sessions=_as_dict(a.get("sessions")),
+            autoApprove=(auto_approve if isinstance(auto_approve, list) else None),
         )
     return defaults, providers, agents
 
@@ -86,11 +93,15 @@ def pick_effective_agent_provider(
 ) -> Tuple[AgentConfig, ProviderConfig]:
     agent_name = cli_agent or defaults.default_agent or (next(iter(agents)) if agents else None)
     if not agent_name or agent_name not in agents:
-        raise KeyError("agent not found")
+        raise KeyError(f"agent {agent_name} not found")
     agent = agents[agent_name]
-    provider_name = cli_provider or agent.provider or defaults.default_provider or (next(iter(providers)) if providers else None)
+    provider_name = (
+        cli_provider
+        or agent.provider
+        or defaults.default_provider
+        or (next(iter(providers)) if providers else None)
+    )
     if not provider_name or provider_name not in providers:
-        raise KeyError("provider not found")
+        raise KeyError(f"provider {provider_name} not found")
     provider = providers[provider_name]
     return agent, provider
-
