@@ -30,18 +30,25 @@ async def test_build_agent_base_params_and_tools_filter(monkeypatch):
     async def fake_resolve_tools(conf: Dict[str, Any], allowed_servers: Optional[List[str]] = None):
         nonlocal captured_allowed
         captured_allowed = list(allowed_servers or []) if allowed_servers is not None else None
+
         # Return a minimal ToolHandle map
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return f"{server}__{name}::{args}"
 
         return {
-            "fs": [ToolHandle(server="fs", name="read", description="", input_schema={}, _executor=_exec)],
+            "fs": [
+                ToolHandle(
+                    server="fs", name="read", description="", input_schema={}, _executor=_exec
+                )
+            ],
         }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
 
     # Act: CLI override should win over agent/provider model
-    agent = await build_agent(config, cli_agent="dev", cli_provider="openai", cli_model_override="cli-model")
+    agent = await build_agent(
+        config, cli_agent="dev", cli_provider="openai", cli_model_override="cli-model"
+    )
 
     # Assert base params and allowed servers filter
     assert getattr(agent.llm, "_base", {}).get("model") == "cli-model"
@@ -49,11 +56,8 @@ async def test_build_agent_base_params_and_tools_filter(monkeypatch):
     assert captured_allowed == ["fs"]
     assert set(agent.tools.keys()) == {"fs"}
     assert len(agent.tools["fs"]) == 1
-    # Ensure agent stores resolved configs
-    assert isinstance(getattr(agent, "provider_conf", None), dict)
-    assert isinstance(getattr(agent, "agent_conf", None), dict)
-    assert agent.provider_conf.get("model") == "prov-model"
-    assert agent.agent_conf.get("model") == "agent-model"
+    # Agent no longer stores provider/agent conf; assert base model only
+    assert getattr(agent.llm, "_base", {}).get("model") == "cli-model"
 
 
 @pytest.mark.asyncio
@@ -68,7 +72,9 @@ async def test_agent_level_mcp_servers_override(monkeypatch):
         # Even if agent defines custom servers, resolver does not override via agent_conf
         "agents": {
             "dev": {
-                "mcp": {"servers": {"agent_only": {"transport": {"type": "stdio"}, "command": "echo"}}}
+                "mcp": {
+                    "servers": {"agent_only": {"transport": {"type": "stdio"}, "command": "echo"}}
+                }
             }
         },
     }
@@ -76,10 +82,18 @@ async def test_agent_level_mcp_servers_override(monkeypatch):
     async def fake_resolve_tools(conf: Dict[str, Any], allowed_servers: Optional[List[str]] = None):
         # Resolver should use global inline servers (no servers_override injection)
         assert "mcp" in conf and "servers" in conf["mcp"]
+
         # Return minimal ToolHandle list for the global server
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return "ok"
-        return {"global_only": [ToolHandle(server="global_only", name="t", description="", input_schema={}, _executor=_exec)]}
+
+        return {
+            "global_only": [
+                ToolHandle(
+                    server="global_only", name="t", description="", input_schema={}, _executor=_exec
+                )
+            ]
+        }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
 
@@ -93,10 +107,12 @@ async def test_tools_filter_applies_over_agent_servers(monkeypatch):
     config: Dict[str, Any] = {
         "default_agent": "dev",
         "providers": {"openai": {"model": "m"}},
-        "mcp": {"servers": {
-            "a": {"transport": {"type": "stdio"}, "command": "echo"},
-            "b": {"transport": {"type": "stdio"}, "command": "echo"},
-        }},
+        "mcp": {
+            "servers": {
+                "a": {"transport": {"type": "stdio"}, "command": "echo"},
+                "b": {"transport": {"type": "stdio"}, "command": "echo"},
+            }
+        },
         "agents": {
             "dev": {
                 "tools": ["b"],
@@ -108,9 +124,15 @@ async def test_tools_filter_applies_over_agent_servers(monkeypatch):
         # Using global servers; allowed should filter to only 'b'
         assert conf.get("mcp", {}).get("servers")
         assert allowed_servers == ["b"]
+
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return "ok"
-        return {"b": [ToolHandle(server="b", name="t", description="", input_schema={}, _executor=_exec)]}
+
+        return {
+            "b": [
+                ToolHandle(server="b", name="t", description="", input_schema={}, _executor=_exec)
+            ]
+        }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
     agent = await build_agent(config, cli_agent="dev", cli_provider="openai")
@@ -123,18 +145,34 @@ async def test_agent_custom_servers_do_not_inherit_global_approvals(monkeypatch)
     config: Dict[str, Any] = {
         "default_agent": "dev",
         "providers": {"openai": {"model": "m"}},
-        "mcp": {"servers": {"global": {"transport": {"type": "stdio"}, "command": "echo", "autoApprove": ["*"]}}},
-        "agents": {"dev": {"mcp": {"servers": {"agent": {"transport": {"type": "stdio"}, "command": "echo"}}}}},
+        "mcp": {
+            "servers": {
+                "global": {"transport": {"type": "stdio"}, "command": "echo", "autoApprove": ["*"]}
+            }
+        },
+        "agents": {
+            "dev": {
+                "mcp": {"servers": {"agent": {"transport": {"type": "stdio"}, "command": "echo"}}}
+            }
+        },
     }
 
     # Patch get_auto_approved_tools path to run our logic but stub discovery
     async def fake_resolve_tools(conf: Dict[str, Any], allowed_servers: Optional[List[str]] = None):
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return "ok"
-        return {"agent": [ToolHandle(server="agent", name="x", description="", input_schema={}, _executor=_exec)]}
+
+        return {
+            "agent": [
+                ToolHandle(
+                    server="agent", name="x", description="", input_schema={}, _executor=_exec
+                )
+            ]
+        }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
     from gptsh.mcp.api import get_auto_approved_tools
+
     await build_agent(config, cli_agent="dev", cli_provider="openai")
     # Compute approvals using effective (agent) config
     approvals = get_auto_approved_tools({**config}, agent_conf=config["agents"]["dev"])  # type: ignore[index]
@@ -148,10 +186,12 @@ async def test_agent_servers_take_precedence_over_global(monkeypatch):
     config: Dict[str, Any] = {
         "default_agent": "dev",
         "providers": {"openai": {"model": "m"}},
-        "mcp": {"servers": {
-            "global": {"transport": {"type": "stdio"}, "command": "echo"},
-            "agent": {"transport": {"type": "stdio"}, "command": "echo"},
-        }},
+        "mcp": {
+            "servers": {
+                "global": {"transport": {"type": "stdio"}, "command": "echo"},
+                "agent": {"transport": {"type": "stdio"}, "command": "echo"},
+            }
+        },
         "agents": {"dev": {"tools": ["agent"]}},
     }
 
@@ -159,9 +199,17 @@ async def test_agent_servers_take_precedence_over_global(monkeypatch):
         # Using global servers; tools filter should narrow to 'agent'
         assert conf.get("mcp", {}).get("servers")
         assert allowed_servers == ["agent"]
+
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return "ok"
-        return {"agent": [ToolHandle(server="agent", name="t", description="", input_schema={}, _executor=_exec)]}
+
+        return {
+            "agent": [
+                ToolHandle(
+                    server="agent", name="t", description="", input_schema={}, _executor=_exec
+                )
+            ]
+        }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
     agent = await build_agent(config, cli_agent="dev", cli_provider="openai")
@@ -185,9 +233,17 @@ async def test_global_inline_mcp_servers_used_when_no_override(monkeypatch):
         assert "servers_override" not in conf["mcp"]
         # tools filter from agent should apply
         assert allowed_servers == ["global_only"]
+
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return "ok"
-        return {"global_only": [ToolHandle(server="global_only", name="t", description="", input_schema={}, _executor=_exec)]}
+
+        return {
+            "global_only": [
+                ToolHandle(
+                    server="global_only", name="t", description="", input_schema={}, _executor=_exec
+                )
+            ]
+        }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
     agent = await build_agent(config, cli_agent="dev", cli_provider="openai")
@@ -211,9 +267,17 @@ async def test_cli_file_paths_ignored_when_inline_servers_present(monkeypatch):
         # Inline servers should take precedence over CLI file paths
         assert conf.get("mcp", {}).get("servers")
         assert allowed_servers == ["inline"]
+
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return "ok"
-        return {"inline": [ToolHandle(server="inline", name="t", description="", input_schema={}, _executor=_exec)]}
+
+        return {
+            "inline": [
+                ToolHandle(
+                    server="inline", name="t", description="", input_schema={}, _executor=_exec
+                )
+            ]
+        }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
     agent = await build_agent(config, cli_agent="dev", cli_provider="openai")
@@ -222,7 +286,9 @@ async def test_cli_file_paths_ignored_when_inline_servers_present(monkeypatch):
 
 @pytest.mark.asyncio
 async def test_mcp_servers_accepts_json_string(monkeypatch):
-    json_payload = '{"mcpServers": {"json_only": {"transport": {"type": "stdio"}, "command": "echo"}}}'
+    json_payload = (
+        '{"mcpServers": {"json_only": {"transport": {"type": "stdio"}, "command": "echo"}}}'
+    )
     config: Dict[str, Any] = {
         "default_agent": "dev",
         "providers": {"openai": {"model": "m"}},
@@ -233,9 +299,17 @@ async def test_mcp_servers_accepts_json_string(monkeypatch):
     async def fake_resolve_tools(conf: Dict[str, Any], allowed_servers: Optional[List[str]] = None):
         # The manager layer will parse the JSON; here we just ensure config includes servers string
         assert isinstance(conf.get("mcp", {}).get("servers"), str)
+
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return "ok"
-        return {"json_only": [ToolHandle(server="json_only", name="t", description="", input_schema={}, _executor=_exec)]}
+
+        return {
+            "json_only": [
+                ToolHandle(
+                    server="json_only", name="t", description="", input_schema={}, _executor=_exec
+                )
+            ]
+        }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
     agent = await build_agent(config, cli_agent="dev", cli_provider="openai")
@@ -252,6 +326,7 @@ async def test_inline_servers_invalid_json_raises(monkeypatch):
         "agents": {"dev": {}},
     }
     from gptsh.core.exceptions import ConfigError
+
     with pytest.raises(ConfigError):
         # Resolution path triggers server parsing
         await build_agent(config, cli_agent="dev", cli_provider="openai")
@@ -265,9 +340,7 @@ async def test_yaml_mapping_with_mcpServers_unwrapped(monkeypatch):
         "mcp": {
             # User pasted JSON-structured content into YAML mapping
             "servers": {
-                "mcpServers": {
-                    "yaml_json": {"transport": {"type": "stdio"}, "command": "echo"}
-                }
+                "mcpServers": {"yaml_json": {"transport": {"type": "stdio"}, "command": "echo"}}
             }
         },
         "agents": {"dev": {"tools": ["yaml_json"]}},
@@ -277,8 +350,117 @@ async def test_yaml_mapping_with_mcpServers_unwrapped(monkeypatch):
         # The client should unwrap mcpServers into servers mapping
         async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
             return "ok"
-        return {"yaml_json": [ToolHandle(server="yaml_json", name="t", description="", input_schema={}, _executor=_exec)]}
+
+        return {
+            "yaml_json": [
+                ToolHandle(
+                    server="yaml_json", name="t", description="", input_schema={}, _executor=_exec
+                )
+            ]
+        }
 
     monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
     agent = await build_agent(config, cli_agent="dev", cli_provider="openai")
     assert set(agent.tools.keys()) == {"yaml_json"}
+
+
+@pytest.mark.asyncio
+async def test_agent_level_autoApprove_server_name(monkeypatch):
+    """Test that agent-level autoApprove with server name auto-approves all tools from that server."""
+    config: Dict[str, Any] = {
+        "default_agent": "dev",
+        "providers": {"openai": {"model": "m"}},
+        "mcp": {
+            "servers": {
+                "rohlik": {"transport": {"type": "stdio"}, "command": "echo"},
+                "other": {"transport": {"type": "stdio"}, "command": "echo"},
+            }
+        },
+        "agents": {
+            "dev": {
+                "autoApprove": ["rohlik"],  # Auto-approve all tools from rohlik server
+            }
+        },
+    }
+
+    async def fake_resolve_tools(conf: Dict[str, Any], allowed_servers: Optional[List[str]] = None):
+        async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
+            return "ok"
+
+        return {
+            "rohlik": [
+                ToolHandle(
+                    server="rohlik", name="search", description="", input_schema={}, _executor=_exec
+                ),
+                ToolHandle(
+                    server="rohlik", name="get", description="", input_schema={}, _executor=_exec
+                ),
+            ],
+            "other": [
+                ToolHandle(
+                    server="other", name="cmd", description="", input_schema={}, _executor=_exec
+                ),
+            ],
+        }
+
+    monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
+    agent = await build_agent(config, cli_agent="dev", cli_provider="openai")
+
+    # Verify the approval policy has rohlik auto-approved with "*" (all tools)
+    assert agent.policy.is_auto_allowed("rohlik", "search") is True
+    assert agent.policy.is_auto_allowed("rohlik", "get") is True
+    # other server should not be auto-approved
+    assert agent.policy.is_auto_allowed("other", "cmd") is False
+
+
+@pytest.mark.asyncio
+async def test_agent_level_autoApprove_tool_name(monkeypatch):
+    """Test that agent-level autoApprove with tool name auto-approves that tool across all servers."""
+    config: Dict[str, Any] = {
+        "default_agent": "dev",
+        "providers": {"openai": {"model": "m"}},
+        "mcp": {
+            "servers": {
+                "fs": {"transport": {"type": "stdio"}, "command": "echo"},
+                "git": {"transport": {"type": "stdio"}, "command": "echo"},
+            }
+        },
+        "agents": {
+            "dev": {
+                "autoApprove": ["read"],  # Auto-approve "read" tool on any server
+            }
+        },
+    }
+
+    async def fake_resolve_tools(conf: Dict[str, Any], allowed_servers: Optional[List[str]] = None):
+        async def _exec(server: str, name: str, args: Dict[str, Any]) -> str:
+            return "ok"
+
+        return {
+            "fs": [
+                ToolHandle(
+                    server="fs", name="read", description="", input_schema={}, _executor=_exec
+                ),
+                ToolHandle(
+                    server="fs", name="write", description="", input_schema={}, _executor=_exec
+                ),
+            ],
+            "git": [
+                ToolHandle(
+                    server="git", name="read", description="", input_schema={}, _executor=_exec
+                ),
+                ToolHandle(
+                    server="git", name="commit", description="", input_schema={}, _executor=_exec
+                ),
+            ],
+        }
+
+    monkeypatch.setattr("gptsh.mcp.tools_resolver.resolve_tools", fake_resolve_tools)
+    agent = await build_agent(config, cli_agent="dev", cli_provider="openai")
+
+    # Verify the "read" tool is auto-approved on all servers
+    assert agent.policy.is_auto_allowed("fs", "read") is True
+    assert agent.policy.is_auto_allowed("git", "read") is True
+    # Other tools should not be auto-approved
+    assert agent.policy.is_auto_allowed("fs", "write") is False
+    assert agent.policy.is_auto_allowed("git", "commit") is False
