@@ -3,42 +3,37 @@ import pytest
 
 @pytest.mark.asyncio
 async def test_core_run_prompt_monkey(monkeypatch):
+    # Also test stream_turn with no-tools path signature
     # Adapted: use ChatSession directly now that core.api is removed
     from gptsh.core.session import ChatSession
+
     class DummyLLM:
         async def complete(self, params):
             return {"choices": [{"message": {"content": "ok"}}]}
+
         async def stream(self, params):
             if False:
                 yield ""
-    agent = type("A", (), {"llm": DummyLLM(), "policy": object(), "tool_specs": []})()
+
+    from gptsh.core.agent import Agent
+    from gptsh.core.approval import DefaultApprovalPolicy
+
+    agent = Agent(
+        name="a", llm=DummyLLM(), tools={}, policy=DefaultApprovalPolicy({}), generation_params={}
+    )
     session = ChatSession.from_agent(agent, progress=None, config={}, mcp=None)
+
+    params, has_tools, model = await session._prepare_params(
+        user_message="hi",
+        no_tools=False,
+    )
+
+    # Now run a small no-tools turn and accept empty result
     chunks = []
     async for t in session.stream_turn(
-        prompt="hi",
-        provider_conf={"model": "m"},
-        agent_conf={},
-        cli_model_override=None,
+        user_message="hi",
         no_tools=True,
-        history_messages=None,
     ):
         chunks.append(t)
-    # For no-tools, test helper stream yields no chunks; accept empty
     assert "".join(chunks) in ("ok", "")
-
-
-@pytest.mark.asyncio
-async def test_core_prepare_stream_params(monkeypatch):
-    from gptsh.core.session import ChatSession
-    class DummyLLM:
-        async def complete(self, params):
-            return {"choices": [{"message": {"content": ""}}]}
-        async def stream(self, params):
-            if False:
-                yield ""
-    agent = type("A", (), {"llm": DummyLLM(), "policy": object(), "tool_specs": []})()
-    session = ChatSession.from_agent(agent, progress=None, config={}, mcp=None)
-    params, has_tools, model = await session._prepare_params(
-        "hi", {"model": "m"}, {}, None, False, None
-    )
-    assert params["model"] == "m" and model == "m"
+    assert params["model"] and model
