@@ -8,8 +8,10 @@ from gptsh.core.session import ChatSession
 class FakeLLM:
     def __init__(self, responses):
         self.responses = list(responses)
+
     async def complete(self, params):
         return self.responses.pop(0)
+
     async def stream(self, params):
         yield ""
 
@@ -20,16 +22,14 @@ async def test_run_prompt_with_agent_simple_no_tools(monkeypatch):
 
     resp = {"choices": [{"message": {"content": "ok"}}]}
     llm = FakeLLM([resp])
-    agent = Agent(name="t", llm=llm, tools={}, policy=DefaultApprovalPolicy({}), generation_params={})
+    agent = Agent(
+        name="t", llm=llm, tools={}, policy=DefaultApprovalPolicy({}), generation_params={}
+    )
     session = ChatSession.from_agent(agent, progress=None, config={}, mcp=None)
     chunks = []
     async for t in session.stream_turn(
-        prompt="hi",
-        provider_conf={"model": "m"},
-        agent_conf={},
-        cli_model_override=None,
+        user_message="hi",
         no_tools=True,
-        history_messages=None,
     ):
         chunks.append(t)
     out = "".join(chunks)
