@@ -2,8 +2,12 @@ import asyncio
 
 
 async def _call_run_turn(**kwargs):
+    from gptsh.core.progress import NoOpProgressReporter
     from gptsh.core.runner import run_turn
 
+    kwargs.pop("progress", None)
+    if kwargs.get("progress_reporter") is None:
+        kwargs["progress_reporter"] = NoOpProgressReporter()
     await run_turn(**kwargs)
 
 
@@ -11,7 +15,6 @@ def test_runner_stream_fallback_when_tool_delta_no_text(monkeypatch):
     # Arrange a Dummy ChatSession that streams no text but indicates tool deltas
     import gptsh.core.runner as runner_mod
 
-
     class DummyLLM:
         def get_last_stream_info(self):
             return {"saw_tool_delta": True, "tool_names": ["fs__read"]}
@@ -25,10 +28,20 @@ def test_runner_stream_fallback_when_tool_delta_no_text(monkeypatch):
         def from_agent(cls, *a, **k):
             return cls()
 
-        async def stream_turn(self, *, prompt, provider_conf, agent_conf, cli_model_override, no_tools, history_messages):
+        async def start(self):
+            pass
+
+        async def stream_turn(
+            self,
+            user_message,
+            no_tools=False,
+        ):
             if False:
                 yield ""  # pragma: no cover
 
+        async def write_pending_osc52(self):
+            pass
+
     # With unified stream_turn, fallback is internal. We assert that runner completes
     # and result_sink contains empty string since DummySession yields nothing.
 
@@ -39,24 +52,19 @@ def test_runner_stream_fallback_when_tool_delta_no_text(monkeypatch):
     agent = object()
     prompt = "do something"
     config = {}
-    provider_conf = {"model": "m"}
     result_sink = []
 
     # Act
     asyncio.run(
         _call_run_turn(
             agent=agent,
-            prompt=prompt,
+            user_message=prompt,
             config=config,
-            provider_conf=provider_conf,
-            agent_conf=None,
-            cli_model_override=None,
             stream=True,
             progress=False,
             output_format="text",
             no_tools=False,
             logger=None,
-            history_messages=None,
             result_sink=result_sink,
         )
     )
@@ -69,7 +77,6 @@ def test_runner_stream_fallback_when_tool_delta_no_text(monkeypatch):
 def test_runner_stream_happy_path_output(monkeypatch, capsys):
     import gptsh.core.runner as runner_mod
 
-
     class DummyLLM:
         def get_last_stream_info(self):
             return {"saw_tool_delta": False}
@@ -83,11 +90,21 @@ def test_runner_stream_happy_path_output(monkeypatch, capsys):
         def from_agent(cls, *a, **k):
             return cls()
 
-        async def stream_turn(self, *, prompt, provider_conf, agent_conf, cli_model_override, no_tools, history_messages):
+        async def start(self):
+            pass
+
+        async def stream_turn(
+            self,
+            user_message,
+            no_tools=False,
+        ):
             yield "hello"
             yield " "
             yield "world"
 
+        async def write_pending_osc52(self):
+            pass
+
     # No external fallback now
 
     monkeypatch.setattr(runner_mod, "ChatSession", DummySession)
@@ -96,23 +113,18 @@ def test_runner_stream_happy_path_output(monkeypatch, capsys):
     agent = object()
     prompt = "hi"
     config = {}
-    provider_conf = {"model": "m"}
     result_sink = []
 
     asyncio.run(
         _call_run_turn(
             agent=agent,
-            prompt=prompt,
+            user_message=prompt,
             config=config,
-            provider_conf=provider_conf,
-            agent_conf=None,
-            cli_model_override=None,
             stream=True,
             progress=False,
             output_format="text",
             no_tools=False,
             logger=None,
-            history_messages=None,
             result_sink=result_sink,
         )
     )
